==> haskell-miniutter-0.5.1.2-48-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-miniutter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 miniutter
version:              0.5.1.2
visibility:           public
id:                   miniutter-0.5.1.2-2ejZTofCS738D1nrWhHMRt
key:                  miniutter-0.5.1.2-2ejZTofCS738D1nrWhHMRt
license:              BSD-3-Clause
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Mikolaj Konarski
homepage:             https://github.com/Mikolaj/miniutter
synopsis:             Simple English clause creation from arbitrary words
description:
    This library helps in generating simple present tense
    English sentences from short, parametrized descriptions.
    In a typical use, the structure of a clause is fixed,
    but the particular words to be used vary in arbitrary ways.
    The main goal of the library is to minimize the API
    complexity and the code size of programs that use it.
    The library doesn'\''t attempt to ban incorrect English sentences,
    but just make the creation of the simple correct ones easy
    and predictable.

category:             Natural Language Processing
abi:                  1d1ed09573332cb40b27a6082f7097b0
exposed:              True
exposed-modules:      NLP.Miniutter.English
import-dirs:          /usr/lib/ghc-9.2.8/site-local/miniutter-0.5.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/miniutter-0.5.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-miniutter
hs-libraries:         HSminiutter-0.5.1.2-2ejZTofCS738D1nrWhHMRt
depends:
    base-4.16.4.0 binary-0.8.9.0 containers-0.6.5.1
    minimorph-0.3.0.1-93DoqbGLulaB7uaHlOA79s text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-miniutter/html/miniutter.haddock
haddock-html:         /usr/share/doc/haskell-miniutter/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-miniutter-0.5.1.2-76.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-miniutter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 miniutter
version:              0.5.1.2
visibility:           public
id:                   miniutter-0.5.1.2-EW4ecbyIy1dAQ69FC1XPfp
key:                  miniutter-0.5.1.2-EW4ecbyIy1dAQ69FC1XPfp
license:              BSD-3-Clause
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Mikolaj Konarski
homepage:             https://github.com/Mikolaj/miniutter
synopsis:             Simple English clause creation from arbitrary words
description:
    This library helps in generating simple present tense
    English sentences from short, parametrized descriptions.
    In a typical use, the structure of a clause is fixed,
    but the particular words to be used vary in arbitrary ways.
    The main goal of the library is to minimize the API
    complexity and the code size of programs that use it.
    The library doesn'\''t attempt to ban incorrect English sentences,
    but just make the creation of the simple correct ones easy
    and predictable.

category:             Natural Language Processing
abi:                  035280879a1e0f474cd2b35da26815c1
exposed:              True
exposed-modules:      NLP.Miniutter.English
import-dirs:          /usr/lib/ghc-9.4.8/site-local/miniutter-0.5.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/miniutter-0.5.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/miniutter-0.5.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-miniutter
hs-libraries:         HSminiutter-0.5.1.2-EW4ecbyIy1dAQ69FC1XPfp
depends:
    base-4.17.2.1 binary-0.8.9.1 containers-0.6.7
    minimorph-0.3.0.1-FGq62Y2nVOE2jk6mc7pvDb text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-miniutter/html/miniutter.haddock
haddock-html:         /usr/share/doc/haskell-miniutter/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
